@@ -22,12 +22,12 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <time.h>
-#include <sys/times.h>
-
 #include "config.h"
 
-#if (HAVE_FFTW3 && HAVE_SNDFILE)
+#if (HAVE_FFTW3 && HAVE_SNDFILE && HAVE_SYS_TIMES_H)
+
+#include <time.h>
+#include <sys/times.h>
 
 #include <sndfile.h>
 #include <math.h>
@@ -38,7 +38,6 @@
 
 #define	MAX_FREQS		4
 #define	BUFFER_LEN		40000
-#define ARRAY_LEN(x)	((int) ((sizeof (x)) / (sizeof ((x) [0]))))
 
 #define SAFE_STRNCAT(dest,src,len)								\
 		{	int safe_strncat_count ;							\
@@ -347,8 +346,8 @@ measure_snr (RESAMPLE_PROG *prog, int *output_samples, int verbose)
 	*output_samples = 0 ;
 
 	for (k = 0 ; k < ARRAY_LEN (snr_test) ; k++)
-	{	unlink ("source.wav") ;
-		unlink ("destination.wav") ;
+	{	remove ("source.wav") ;
+		remove ("destination.wav") ;
 
 		if (verbose)
 			printf ("       SNR test #%d : ", k) ;
@@ -425,7 +424,7 @@ find_attenuation (double freq, RESAMPLE_PROG *prog, int verbose)
 
 	generate_source_wav ("source.wav", &freq, 1, prog->format) ;
 
-	unlink (filename) ;
+	remove (filename) ;
 
 	snprintf (command, sizeof (command), prog->convert_cmd, 88189) ;
 	SAFE_STRNCAT (command, " >/dev/null", sizeof (command)) ;
